==> trivianpm-1.4.0.tgz: package/index.js <==
let paises = [
{
  question: '¿Que pais es este?',
  image: 'https://cdn.discordapp.com/attachments/845496899514531863/847276007974371348/pais.png',
  answers: ["Argelia","Brasil","India"],
  answer: 'Argelia'
},
{
  question: '¿Como se llama este alimento?',
  image: 'https://cdn.discordapp.com/attachments/845496899514531863/847276357435916298/Argentina.jpg',
  answers: ['Dulce',"Cerebritos","Alfajor"],
  answer: 'Alfajor'
},
{
  question: '¿Cual es el pais de el que proviene este alimento?',
  image: 'https://cdn.discordapp.com/attachments/845496899514531863/847276796952051752/otac.jpeg',
  answers: ['Argentina','Chile','Mexico'],
  answer:  'Mexico'
}]
let cultura = [
{
  question: '¿En que decada se invento el televisor?',
  image: 'https://cdn.discordapp.com/attachments/845496899514531863/847277297110614057/descarga_1.jpeg',
  answers: ["1010","1920","1930"],
  answer: "1920"
},
{
  question: '¿En que siclo se invento la camara fotografica?',
  image: 'https://cdn.discordapp.com/attachments/845496899514531863/847277870686142495/foto.jpg',
  answers: ["1900","1600","1800"],
  answer:"1600"
}]
const ficticio = [
{
  question: '¿Quien es este personaje?',
  image: 'https://cdn.discordapp.com/attachments/845496899514531863/847269357406519316/descarga.jpeg',
  answers: ['Peppa pig',"Winie Pu","Winnie Pooh"],
  answer: 'Ẁinnie Pooh'
},
{
  question: '¿Como se llama este lugar ficticio?',
  image: 'https://cdn.discordapp.com/attachments/845496899514531863/847272197936513094/incognity.png',
  answers: ["Torre de los vengadores",'Torre DC',"Torre Marvel"],
  answer: 'Torre de los vengadores'
},
{
  question: '¿De que serie / pelicula es este lenguaje?',
  image: 'https://cdn.discordapp.com/attachments/845496899514531863/847273071160459274/abecedario.jpeg',
  answers: ['Star Wars',"Stark Trek","Star Land"],
  answer: 'Stark Trek'
},
{
  question: '¿Como se llama este continente ficticio?',
  image: 'https://cdn.discordapp.com/attachments/845496899514531863/847274252041846784/Kvp_31.jpg',
  answers: ["Ooo","Post apocaliptico","Iii"],
  answer: 'Ooo'
},
{
  question: '¿Como se llama este personaje?',
  image: 'https://cdn.discordapp.com/attachments/845496899514531863/847274853148655636/41bC-NFUEL._AC_.jpg',
  answers: ["Bmo","Finn","Jake"],
  answer: 'Finn'
}]

const famosos = [
{
  question: '¿Como se llama esta persona?',
  image: 'https://cdn.discordapp.com/attachments/843326059507089418/847543330223947847/descarga_2.jpeg',
  answers: ["Reina Isabel","Reina Isabel Primera","Reina Isabel Segunda"],
  answer: "Reina Isabel Segunda"
},
{
  question: '¿Cual es el canal de youtube de este tipo?',
  image: 'https://cdn.discordapp.com/attachments/843326059507089418/847543716981375046/be28417895a308dff51fbbcc7d3deb47.jpg',
  answers: ["Fernanfloo","Nico Core","JuegaGerman"],
  answer: 'JuegaGerman'
}]
module.exports = {
  
  const ficticio = Math.floor(Math.random()*ficticio.length)

  const kult = Math.floor(Math.random()*cultura.length)

  const famous = Math.floor(Math.random()*famosos.length)

  const country = Math.floor(Math.random()*famosos.length)

  fiction : async function ( ) {
    return ficticio
  },
  cultura : async function ( ) {
    return kult
  },
  famosos : async function ( ) {
    return famous
  },
  pais : async function ( ) {
    return country
  }
}

==> trivianpm-1.8.0.tgz: package/index.js <==
let paises = [
{
  question: '¿Que pais es este?',
  image: 'https://cdn.discordapp.com/attachments/845496899514531863/847276007974371348/pais.png',
  answers: ["Argelia","Brasil","India"],
  answer: 'Argelia'
},
{
  question: '¿Como se llama este alimento?',
  image: 'https://cdn.discordapp.com/attachments/845496899514531863/847276357435916298/Argentina.jpg',
  answers: ['Dulce',"Cerebritos","Alfajor"],
  answer: 'Alfajor'
},
{
  question: '¿Cual es el pais de el que proviene este alimento?',
  image: 'https://cdn.discordapp.com/attachments/845496899514531863/847276796952051752/otac.jpeg',
  answers: ['Argentina','Chile','Mexico'],
  answer:  'Mexico'
}]
let cultura = [
{
  question: '¿En que decada se invento el televisor?',
  image: 'https://cdn.discordapp.com/attachments/845496899514531863/847277297110614057/descarga_1.jpeg',
  answers: ["1010","1920","1930"],
  answer: "1920"
},
{
  question: '¿En que siclo se invento la camara fotografica?',
  image: 'https://cdn.discordapp.com/attachments/845496899514531863/847277870686142495/foto.jpg',
  answers: ["1900","1600","1800"],
  answer:"1600"
}]
const ficticio = [
{
  question: '¿Quien es este personaje?',
  image: 'https://cdn.discordapp.com/attachments/845496899514531863/847269357406519316/descarga.jpeg',
  answers: ['Peppa pig',"Winie Pu","Winnie Pooh"],
  answer: 'Ẁinnie Pooh'
},
{
  question: '¿Como se llama este lugar ficticio?',
  image: 'https://cdn.discordapp.com/attachments/845496899514531863/847272197936513094/incognity.png',
  answers: ["Torre de los vengadores",'Torre DC',"Torre Marvel"],
  answer: 'Torre de los vengadores'
},
{
  question: '¿De que serie / pelicula es este lenguaje?',
  image: 'https://cdn.discordapp.com/attachments/845496899514531863/847273071160459274/abecedario.jpeg',
  answers: ['Star Wars',"Stark Trek","Star Land"],
  answer: 'Stark Trek'
},
{
  question: '¿Como se llama este continente ficticio?',
  image: 'https://cdn.discordapp.com/attachments/845496899514531863/847274252041846784/Kvp_31.jpg',
  answers: ["Ooo","Post apocaliptico","Iii"],
  answer: 'Ooo'
},
{
  question: '¿Como se llama este personaje?',
  image: 'https://cdn.discordapp.com/attachments/845496899514531863/847274853148655636/41bC-NFUEL._AC_.jpg',
  answers: ["Bmo","Finn","Jake"],
  answer: 'Finn'
}]

const famosos = [
{
  question: '¿Como se llama esta persona?',
  image: 'https://cdn.discordapp.com/attachments/843326059507089418/847543330223947847/descarga_2.jpeg',
  answers: ["Reina Isabel","Reina Isabel Primera","Reina Isabel Segunda"],
  answer: "Reina Isabel Segunda"
},
{
  question: '¿Cual es el canal de youtube de este tipo?',
  image: 'https://cdn.discordapp.com/attachments/843326059507089418/847543716981375046/be28417895a308dff51fbbcc7d3deb47.jpg',
  answers: ["Fernanfloo","Nico Core","JuegaGerman"],
  answer: 'JuegaGerman'
}]
module.exports = {

  fiction : async function ( ) {
    return Math.floor(Math.random()*ficticio.length)
  },
  cultura : async function ( ) {
    return Math.floor(Math.random()*cultura.length)
  },
  famosos : async function ( ) {
    return  Math.floor(Math.random()*famosos.length)
  },
  pais : async function ( ) {
    return Math.floor(Math.random()*famosos.length)
  }
}
